@@ -1,8 +1,8 @@
 /** ===========================================================
  * @file
  *
- * This file is a part of digiKam project
- * <a href="http://www.digikam.org">http://www.digikam.org</a>
+ * This file is a part of KDE project
+ *
  *
  * @date   2009-12-08
  * @brief  Marble-backend for KGeoMap
@@ -73,7 +73,7 @@ public:
     BMInternalWidgetInfo()
     {
 #ifdef KGEOMAP_MARBLE_ADD_LAYER
-        bmLayer = 0;
+        bmLayer = nullptr;
 #endif
     }
 
@@ -94,13 +94,13 @@ class BackendMarble::Private
 public:
 
     Private()
-      : marbleWidget(0),
-        actionGroupMapTheme(0),
-        actionGroupProjection(0),
-        actionGroupFloatItems(0),
-        actionShowCompass(0),
-        actionShowOverviewMap(0),
-        actionShowScaleBar(0),
+      : marbleWidget(nullptr),
+        actionGroupMapTheme(nullptr),
+        actionGroupProjection(nullptr),
+        actionGroupFloatItems(nullptr),
+        actionShowCompass(nullptr),
+        actionShowOverviewMap(nullptr),
+        actionShowScaleBar(nullptr),
         cacheMapTheme(QLatin1String("atlas")),
         cacheProjection(QLatin1String("spherical")),
         cacheShowCompass(false),
@@ -126,7 +126,7 @@ public:
         blockingZoomWhileChangingTheme(false),
         trackCache()
 #ifdef KGEOMAP_MARBLE_ADD_LAYER
-        , bmLayer(0)
+        , bmLayer(nullptr)
 #endif
     {
     }
@@ -262,19 +262,19 @@ void BackendMarble::releaseWidget(KGeoMapInternalWidgetInfo* const info)
 
     if (intInfo.bmLayer)
     {
-        intInfo.bmLayer->setBackend(0);
+        intInfo.bmLayer->setBackend(nullptr);
     }
 #endif
 
     disconnect(d->marbleWidget, SIGNAL(zoomChanged(int)),
                this, SLOT(slotMarbleZoomChanged(int)));
 
-    info->currentOwner = 0;
+    info->currentOwner = nullptr;
     info->state        = KGeoMapInternalWidgetInfo::InternalWidgetReleased;
 
-    d->marbleWidget    = 0;
+    d->marbleWidget    = nullptr;
 #ifdef KGEOMAP_MARBLE_ADD_LAYER
-    d->bmLayer         = 0;
+    d->bmLayer         = nullptr;
 #endif /* KGEOMAP_MARBLE_ADD_LAYER */
 
     emit(signalBackendReadyChanged(backendName()));
@@ -303,7 +303,7 @@ void BackendMarble::setCenter(const GeoCoordinates& coordinate)
 
 bool BackendMarble::isReady() const
 {
-    return d->marbleWidget!=0;
+    return d->marbleWidget!=nullptr;
 }
 
 void BackendMarble::zoomIn()
@@ -391,7 +391,7 @@ void BackendMarble::createActions()
 
 void BackendMarble::addActionsToConfigurationMenu(QMenu* const configurationMenu)
 {
-    KGEOMAP_ASSERT(configurationMenu!=0);
+    KGEOMAP_ASSERT(configurationMenu!=nullptr);
 
     configurationMenu->addSeparator();
 
@@ -492,7 +492,7 @@ void BackendMarble::setMapTheme(const QString& newMapTheme)
 
 void BackendMarble::saveSettingsToGroup(KConfigGroup* const group)
 {
-    KGEOMAP_ASSERT(group != 0);
+    KGEOMAP_ASSERT(group != nullptr);
 
     if (!group)
     {
@@ -508,7 +508,7 @@ void BackendMarble::saveSettingsToGroup(KConfigGroup* const group)
 
 void BackendMarble::readSettingsFromGroup(const KConfigGroup* const group)
 {
-    KGEOMAP_ASSERT(group != 0);
+    KGEOMAP_ASSERT(group != nullptr);
 
     if (!group)
     {
@@ -730,7 +730,7 @@ void BackendMarble::marbleCustomPaint(Marble::GeoPainter* painter)
 
             QPoint markerOffsetPoint;
             QPixmap markerPixmap;
-            const bool haveMarkerPixmap = modelHelper->itemIcon(currentIndex, &markerOffsetPoint, 0, &markerPixmap, 0);
+            const bool haveMarkerPixmap = modelHelper->itemIcon(currentIndex, &markerOffsetPoint, nullptr, &markerPixmap, nullptr);
 
             if (!haveMarkerPixmap || markerPixmap.isNull())
             {
@@ -1346,7 +1346,7 @@ bool BackendMarble::eventFilter(QObject *object, QEvent *event)
                 QPoint newMarkerPoint = mouseEvent->pos() - d->mouseMoveCenterOffset;
                 QPoint snapPoint;
 
-                if (findSnapPoint(newMarkerPoint, &snapPoint, 0, 0))
+                if (findSnapPoint(newMarkerPoint, &snapPoint, nullptr, nullptr))
                 {
                     newMarkerPoint = snapPoint;
                 }
@@ -1394,7 +1394,7 @@ bool BackendMarble::eventFilter(QObject *object, QEvent *event)
 
             QPair<int, QModelIndex> snapTargetIndex(-1, QModelIndex());
             GeoCoordinates newCoordinates;
-            bool haveValidPoint = findSnapPoint(dropMarkerPoint, 0, &newCoordinates, &snapTargetIndex);
+            bool haveValidPoint = findSnapPoint(dropMarkerPoint, nullptr, &newCoordinates, &snapTargetIndex);
 
             if (!haveValidPoint)
             {
